![yagdrive-logo](https://raw.githubusercontent.com/sdelquin/yagdrive/main/yagdrive-logo.svg)

**Yet Another Google Drive API Python wrapper!**

YagDrive is a Python package based on [PyDrive](https://pythonhosted.org/PyDrive/) which aims to simplify and enhance the operations over the [Google Drive API](https://developers.google.com/drive).

# Installing

```console
$ pip install yagdrive
```

# A Simple Example

```python
>>> from yagdrive import GDrive

>>> drive = GDrive()
>>> drive.put('/home/yagdrive/hello.json')
```

# Links

- Documentation: https://yagdrive.readthedocs.org/
- PyPI Releases: https://pypi.org/project/yagdrive/
- Source Code: https://github.com/sdelquin/yagdrive/
- Issue Tracker: https://github.com/sdelquin/yagdrive/issues/
- Changes: https://github.com/sdelquin/yagdrive/blob/main/CHANGELOG.md
- License: https://github.com/sdelquin/yagdrive/blob/main/LICENSE
